@@ -7,7 +7,7 @@
 
 #![allow(clippy::borrow_deref_ref)]
 
-use crate::domain::Component;
+use crate::domain::{Component, Meta};
 use anyhow::Error;
 use auditor::domain::ValidName;
 use chrono::{offset::TimeZone, Utc};
@@ -16,13 +16,10 @@ use pyo3::prelude::*;
 use pyo3::types::PyDateTime;
 use pyo3_chrono::NaiveDateTime;
 
-/// Record(record_id: str, site_id: str, user_id: str, group_id: str, start_time: datetime.datetime)
+/// Record(record_id: str, start_time: datetime.datetime)
 /// A Record represents a single accountable unit. It consists of meta information such as
 ///
 /// * ``record_id``: Uniquely identifies the record
-/// * ``site_id``: Site identifier
-/// * ``user_id``: User identifier
-/// * ``group_id``: Group identifier
 /// * ``start_time``: Timestamp from when the resource was available.
 ///
 /// .. note::
@@ -43,16 +40,12 @@ use pyo3_chrono::NaiveDateTime;
 /// Components are added via ``with_component``. Call this method multiple times for adding
 /// multiple components.
 ///
+/// Meta information is added via `with_meta`.
+///
 /// The individual fields of the record can be accessed using the getter methods described below.
 ///
 /// :param record_id: Unique record identifier
 /// :type record_id: str
-/// :param site_id: Site identifier
-/// :type site_id: str
-/// :param user_id: User identifier
-/// :type user_id: str
-/// :param group_id: Group identifier
-/// :type group_id: str
 /// :param start_time: Timestamp from which the resource became available
 /// :type group_id: datetime.datetime
 #[pyclass]
@@ -64,21 +57,13 @@ pub struct Record {
 #[pymethods]
 impl Record {
     #[new]
-    fn new(
-        record_id: String,
-        site_id: String,
-        user_id: String,
-        group_id: String,
-        start_time: &PyDateTime,
-    ) -> Result<Self, Error> {
+    fn new(record_id: String, start_time: &PyDateTime) -> Result<Self, Error> {
         let start_time: NaiveDateTime = start_time.extract()?;
         let start_time = Utc.from_utc_datetime(&start_time.into());
         Ok(Record {
             inner: auditor::domain::Record {
                 record_id: ValidName::parse(record_id)?.as_ref().to_owned(),
-                site_id: Some(ValidName::parse(site_id)?.as_ref().to_owned()),
-                user_id: Some(ValidName::parse(user_id)?.as_ref().to_owned()),
-                group_id: Some(ValidName::parse(group_id)?.as_ref().to_owned()),
+                meta: None,
                 components: Some(vec![]),
                 start_time: Some(start_time),
                 stop_time: None,
@@ -87,6 +72,16 @@ impl Record {
         })
     }
 
+    /// with_meta(meta: Meta)
+    /// Adds Meta to the record.
+    ///
+    /// :param meta: Meta datastructure
+    /// :type meta: Meta
+    fn with_meta(mut self_: PyRefMut<Self>, meta: Meta) -> Result<PyRefMut<Self>, Error> {
+        self_.inner.meta = Some(meta.inner);
+        Ok(self_)
+    }
+
     /// with_component(component: Component)
     /// Adds a component to the record. Use this method multiple times to attach multiple
     /// components.
@@ -127,24 +122,6 @@ impl Record {
         self.inner.record_id.clone()
     }
 
-    /// Returns the site_id
-    #[getter]
-    fn site_id(&self) -> Option<String> {
-        self.inner.site_id.clone()
-    }
-
-    /// Returns the user_id
-    #[getter]
-    fn user_id(&self) -> Option<String> {
-        self.inner.user_id.clone()
-    }
-
-    /// Returns the group_id
-    #[getter]
-    fn group_id(&self) -> Option<String> {
-        self.inner.group_id.clone()
-    }
-
     /// Returns the components
     ///
     /// Returns None if no components are attached, otherwise returns a list of ``Component`` s.
@@ -156,6 +133,14 @@ impl Record {
             .map(|components| components.iter().cloned().map(Component::from).collect())
     }
 
+    /// Returns the meta dict
+    ///
+    /// Returns None if no meta is available, otherwise returns a dict of meta information.
+    #[getter]
+    fn meta(&self) -> Option<Meta> {
+        self.inner.meta.clone().map(Meta::from)
+    }
+
     /// Returns the start_time
     #[getter]
     fn start_time(&self, py: Python) -> Option<Py<PyAny>> {
